Context

Struct Context 

pub struct Context { /* private fields */ }

Implementations

Source

impl Context

pub fn new() -> Self

Create a new wgui context with default options (localhost, port 9080, title “wgui”).

pub fn with_port(start_port: u16) -> Self

Create a new wgui context starting port search from start_port.

pub fn with_options(opts: ContextOptions) -> Self

Create a new wgui context with the given options.

pub fn http_port(&self) -> u16

Returns the HTTP port the UI is served on.

pub fn ws_port(&self) -> u16

Returns the WebSocket port.

pub fn window(&mut self, name: &str) -> Window<'_>

Get or create a named window. Call widget methods on the returned Window.

pub fn end_frame(&mut self)

Finish the current frame: reconcile with previous frame, send diffs over WS.