pub struct Context { /* private fields */ }Implementations
Sourceimpl Context
impl Context
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new wgui context with default options (localhost, port 9080, title “wgui”).
Sourcepub fn with_port(start_port: u16) -> Self
pub fn with_port(start_port: u16) -> Self
Create a new wgui context starting port search from start_port.
Sourcepub fn with_options(opts: ContextOptions) -> Self
pub fn with_options(opts: ContextOptions) -> Self
Create a new wgui context with the given options.